SPARTOO.PT

A Spartoo utiliza cookies. Ao continuar a navegar no site, aceita a utilização dos mesmos.
Aceito.
Serviço cliente 308 802 547
Segunda - Sexta : 8h - 17h
A minha conta | As minhas encomendas | Como fazer uma devolução? | Ganhe 10 euros | Os meus Favoritos | Ajuda
Início
entrega
gratuita
em 7 dias úteis
devolução
gratuita
até 30 dias
O meu cesto (0)

# Pedido de palavra-passe

## Caso não se lembre da sua palavra-passe, digite o seu e-mail no campo abaixo e receberá um e-mail para proceder à alteração da palavra-passe.

E-mail
Voltar
INÍCIO | MARCAS | ESTILOS | BOLSAS / MALAS | ACESSÓRIOS | NOVIDADES | PREÇOS BAIXOS | TAMANHOS GRANDES | PESQUISA | AGENDA DE TENDÊNCIAS
Quem é a SPARTOO? | F.A.Q. | As vantagens | C.G.V. | *Condições das ofertas em curso | Marketplace | Política de privacidade | Contacto
Operações em curso

Operações promocionais: Todas as nossas ofertas são válidas no limite do stock disponível.

Marcas excluídas da nossas promoções
Os códigos promocionais da SPARTOO não são válidos nas seguintes marcas: Mellow Yellow, Sendra Boots, Chie Mihara, Minnetonka, Samsonite

As reduções da campanha "christmas days" não se aplicam às marcas:
Pablosky, Ash, No Name, Schmoove, Bunker, Panama Jack, Gabor, Clarks, UGG, Mellow Yellow, Spiral, Ted Baker, Victoria, Havaianas, Tamaris, TBS, El Naturalista, Camper, Hunter, Lacoste, Sendra boots, Chie Mihara, Meindl, Primigi, Minnetonka, Timberland, Barbara Rihl, Thierry Mugler, Le Temps des cerises, IKKS, Tann's, Eastpak, Nat & Nin, Clarks, Abaco, Petite Mendigote, Arthur & Aston, Mac Douglas, Upla, Petite Mendigote, Samsonite, Hugo Boss, Freelance, Jean-Baptiste Rautureau, Versace, Michael Michael Kors, Michael Kors, Kenzo, Marc by Marc Jacobs, Les voiles de Saint Tropez, Canada Goose

Produtos Parceiro
- Os códigos promocionais da SPARTOO não são válidos nos "produtos dos parceiros".
- A entrega e a devolução podem não ser gratuitas quando os produtos estão marcados como "Produto Parceiro"

O seu navegador não aceita cookies!
Deve activá-los para aceder a todas as funcionalidades do nosso site.
Para saber como ativar os cookies, clique aqui.